#[non_exhaustive]pub enum Error {
Show 14 variants
PrivateKeyGen,
AuthlyCAmissingInEtc,
AuthlyCA(&'static str),
Identity(&'static str),
Tls(&'static str),
EnvironmentNotInferrable,
InvalidAltNames,
Unauthorized(Error),
Network(Error),
InvalidAccessToken(Error),
Codec(Error),
InvalidPropertyAttributeLabel,
AccessDenied,
Unclassified(Error),
}Expand description
Errors that can happen either during client configuration or while communicating over the network.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PrivateKeyGen
Error generating a private key.
AuthlyCAmissingInEtc
AuthlyCA not inferred from standard location
AuthlyCA(&'static str)
A problem with the Authly Certificate Authority.
Identity(&'static str)
A problem with the client identity.
Tls(&'static str)
A problem with TLS infrastructure
EnvironmentNotInferrable
Automatic environment inference did not work.
InvalidAltNames
Invalid Common Name in certificate signing request.
A party was not authenticated or an operation was forbidden.
Network(Error)
A network problem.
InvalidAccessToken(Error)
An access token problem.
Codec(Error)
A codec problem, usually related to network protocols.
InvalidPropertyAttributeLabel
Invalid namespace/property/attribute label
AccessDenied
Access control enforcement has resulted in “deny”.
Unclassified(Error)
Other type of unclassified error.