pub struct ServiceMetadata { /* private fields */ }Expand description
A structure which provides various pieces of information about the service.
Metadata is not required for the service to function, but can be used optionally to convey application-specific data from the Authly database to the service.
Implementations
Sourceimpl ServiceMetadata
impl ServiceMetadata
Sourcepub fn entity_id(&self) -> ServiceId
pub fn entity_id(&self) -> ServiceId
Get the entity ID (ServiceId) of the Authly service this client identifies as.
Sourcepub fn namespaces(&self) -> &[NamespaceMetadata]
pub fn namespaces(&self) -> &[NamespaceMetadata]
Get the list of namespace metadata for the namespaces this service has access to.
The list comes in no particular order and should be interpreted as a set.